@@ -2,7 +2,7 @@ package Catalyst::Plugin::File::RotateLogs;
 use strict;
 use warnings;
 use MRO::Compat;
-our $VERSION = "0.02";
+our $VERSION = "0.03";
 
 sub setup {
     my $c = shift;
@@ -12,7 +12,9 @@ sub setup {
         linkname => "${home}/root/error_log",
         rotationtime => 86400, #default 1day
         maxage => 86400 * 3,   #3day
+        autodump => 0,
     };
+    $config->{maxage} = int eval($config->{maxage});
     $c->log((__PACKAGE__ . '::Backend')->new($config));
     return $c->maybe::next::method(@_);
 }
@@ -26,13 +28,17 @@ BEGIN { extends 'Catalyst::Log' }
 
 my $ROTATE_LOGS; 
 my $CALLER_DEPTH = 1; 
+my $AUTODUMP     = 0;
 
 sub new {
     my $class = shift;
-    my $args  = shift;
+    my $config  = shift;
+
+    $AUTODUMP = $config->{autodump} //= 0;
+    delete $config->{autodump};
 
     my $self  = $class->next::method();
-    $ROTATE_LOGS = File::RotateLogs->new($args);
+    $ROTATE_LOGS = File::RotateLogs->new($config);
 
     return $self;
 }
@@ -41,6 +47,12 @@ sub new {
     foreach my $handler (qw/debug info warn error fatal/) {
         override $handler => sub {
             my ($self, $message) = @_; 
+            if ($AUTODUMP && ref($message) ) {
+                local $Data::Dumper::Terse = 1;
+                local $Data::Dumper::Indent = 0;
+                local $Data::Dumper::Sortkeys = 1;
+                $message = Data::Dumper::Dumper($message);
+            }
             my ($package, $file, $line) = caller($CALLER_DEPTH); 
             #todo: enables to change a format
             $ROTATE_LOGS->print(sprintf(qq{%s: [%s] [%s] %s at %s line %s\n},
@@ -71,10 +83,9 @@ Catalyst::Plugin::File::RotateLogs - Catalyst Plugin for File::RotateLogs
     $c->log->info("hello catalyst"); 
 
     # Catalyst configuration by default (e. g. in YAML format):
-    # please 'mkdir logs'
     File::RotateLogs:
-        logfile: './logs/error.log.%Y%m%d%H' 
-        linkname: './logs/error.log'
+        logfile: './root/error.log.%Y%m%d%H' 
+        linkname: './root/error.log'
         rotationtime: 86400
         maxage: 86400 * 3  
 
